import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)
import java.awt.Color;

/**
 * ButtonLabel is a variation of a Label that activates a Trigger-implemented class when clicked. Includes a background.
 * 
 * @author MathManiac 
 * @version 1.0
 */
public class ButtonLabel  extends Label
{
    
    protected Color fillColor = Color.WHITE;
    protected Trigger target;
    
    public ButtonLabel(String txt, Color clr, Trigger trgt) {
        
        super(txt);
        label = txt;
        if(clr != null) fillColor = clr;
        target = trgt;
        generateButton();
        
    }
    
    public void act() {
        
        if (Greenfoot.mouseClicked(this))
            target.activate();
        
    }
    
    public void setFillColor(Color clr) {
        
        fillColor = clr;
        generateButton();
        
    }
    
    protected void generateLabel() {generateButton();}
    protected void generateButton() {generateButton(label, fillColor);}
    
    protected void generateButton(String txt, Color clr) {
        
        GreenfootImage img = new GreenfootImage(txt.length() * 8, 30);
        img.setColor(clr);
        img.fill();
        img.setColor(Color.BLACK);
        img.drawString(txt, (txt.length()/2), 20);
        setImage(img);
        
    }
    
}
